cordova.define("cordova-plugin-r3t-sensors.changed-sensor", function(require, exports, module) {
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var cordova_1 = require("cordova");
var ChangedSensor = /** @class */ (function () {
    function ChangedSensor(className) {
        this.className = className;
        this.configured = false; // 没有配置
        this.started = false; // 没有开始
        this.lastError = null; // 最后的错误和数据
        this.lastData = null;
    }
    ChangedSensor.prototype.configure = function (options, callbackFn) {
        if (callbackFn === void 0) { callbackFn = null; }
        if (this.configured) {
            return;
        }
        this.configured = true; // 注意：同步设置已成功，确保配置不会被重入
        cordova_1.exec(function () {
            if (callbackFn != null) {
                callbackFn();
            }
        }, null, this.className, 'configure', [options]);
    };
    ChangedSensor.prototype.start = function (callbackFn) {
        var _this = this;
        if (callbackFn === void 0) { callbackFn = null; }
        if (!this.configured) {
            return;
        }
        if (this.started) {
            return;
        }
        this.started = true; // 同步设定，认为启动
        cordova_1.exec(function (data) {
            if (data.timestamp == null)
                data.timestamp = new Date().getTime();
            _this.lastData = data;
            _this.lastError = null;
            if (callbackFn != null)
                callbackFn(null, data);
        }, function (error) {
            if (error == null || error.code == null) {
                console.error(_this.className + ' internal error:', error);
                return;
            }
            if (error.timestamp == null)
                error.timestamp = new Date().getTime();
            _this.lastData = null;
            _this.lastError = error;
            if (callbackFn != null)
                callbackFn(error, null);
        }, this.className, 'start', []);
    };
    ChangedSensor.prototype.stop = function (callbackFn) {
        var _this = this;
        if (callbackFn === void 0) { callbackFn = null; }
        if (!this.started) {
            return;
        }
        this.started = false; // 注意：同步确定
        cordova_1.exec(function () {
            _this.lastData = null;
            _this.lastError = null;
            if (callbackFn != null)
                callbackFn();
        }, null, this.className, 'stop', []);
    };
    ;
    ChangedSensor.prototype.get = function () {
        if (!this.started)
            return null;
        if (this.lastError != null)
            return this.lastError;
        else
            return this.lastData;
    };
    ;
    return ChangedSensor;
}());
exports.default = ChangedSensor;

});
