cordova.define("cordova-plugin-r3t-sensors.timed-sensor", function(require, exports, module) {
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var cordova_1 = require("cordova");
var TimedSensor = /** @class */ (function () {
    function TimedSensor(className) {
        this.className = className;
        this.configured = false; // 没有配置
        this.started = false; // 没有开始
        this.lastError = null; // 最后的错误和数据
        this.lastData = null;
        this.timer = null;
    }
    TimedSensor.prototype.configure = function (options, callbackFn) {
        if (callbackFn === void 0) { callbackFn = null; }
        if (this.configured) {
            return;
        }
        this.configured = true; // 注意：同步设置已成功，确保配置不会被重入
        cordova_1.exec(function () {
            if (callbackFn != null) {
                callbackFn();
            }
        }, null, this.className, 'configure', [options]);
    };
    TimedSensor.prototype.start = function (callbackFn) {
        if (callbackFn === void 0) { callbackFn = null; }
        if (!this.configured) {
            return;
        }
        if (this.started) {
            return;
        }
        this.started = true;
        this.callbackFn = callbackFn;
        this.current(); // 首先运行一次，之后每隔60秒运行一次
        this.timer = setInterval(this.current.bind(this), 60 * 1000);
    };
    TimedSensor.prototype.stop = function (callbackFn) {
        if (callbackFn === void 0) { callbackFn = null; }
        if (!this.started) {
            return;
        }
        this.started = false;
        this.callbackFn = null;
        this.lastError = null;
        this.lastData = null;
        clearInterval(this.timer);
        this.timer = null;
    };
    TimedSensor.prototype.get = function () {
        if (!this.started)
            return null;
        if (this.lastError != null)
            return this.lastError;
        else
            return this.lastData;
    };
    TimedSensor.prototype.current = function () {
        var _this = this;
        cordova_1.exec(function (data) {
            if (data.timestamp == null) {
                data.timestamp = new Date().getTime();
            }
            _this.lastData = data;
            _this.lastError = null;
            if (_this.callbackFn != null)
                _this.callbackFn(null, data);
        }, function (error) {
            if (error == null || error.code == null) {
                console.error(_this.className + ' internal error:', error);
                return;
            }
            if (error.timestamp == null)
                error.timestamp = new Date().getTime();
            _this.lastData = null;
            _this.lastError = error;
            if (_this.callbackFn != null)
                _this.callbackFn(error, null);
        }, this.className, 'current', []);
    };
    return TimedSensor;
}());
exports.default = TimedSensor;

});
